{% comment %}{% load assets %}{% assets "xiti_js" %}
    <script type="text/javascript" src="{{ ASSET_URL }}">
</script>{% endassets %}{% endcomment %}{% load static from staticfiles %}
<script type="text/javascript" src="{% static "js/xtcore.js" %}"></script>